[![PyPI](https://img.shields.io/pypi/v/dis-snek)](https://pypi.org/project/dis-snek/)
[![Discord](https://img.shields.io/discord/870046872864165888?color=%235865F2&label=Server&logo=discord&logoColor=%235865F2)](https://discord.gg/hpfNhH8BsY)
[![Documentation Status](https://readthedocs.org/projects/dis-snek/badge/?version=latest)](https://dis-snek.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![CodeQL](https://img.shields.io/github/workflow/status/LordOfPolls/dis-snek/CodeQL/master?label=CodeQL&logo=Github)](https://github.com/LordOfPolls/dis_snek/actions/workflows/codeql-analysis.yml)
[![black-formatted](https://img.shields.io/github/workflow/status/LordOfPolls/dis-snek/black-action/master?label=Black%20Formatted&logo=Github)](https://github.com/LordOfPolls/dis_snek/actions/workflows/black.yml)

# Dis-Snek

This is `Dis-Snek`, an API wrapper for Discord, written in Python. This wrapper is designed to be easy to use, and easily modified to suit your needs. 

## "Is this just another discord.py fork?"

While this library shares some features or styles with discord.py, it's completely separate from them. We think discord.py is a fantastic library, but we disagree with the direction and design decisions made by it.

## "Can I contribute to this project?"

Of course! You can contribute to this project by submitting a Pull Request here. We also have a [Trello Board](https://trello.com/b/LVjnmYKt/dev-board) where you can see what we are working towards - feel free to do anything there.

## Links:

- Support Server: https://discord.gg/NTSHu97tHg
- Documentation:  https://dis-snek.rtfd.io/
- Trello: https://trello.com/b/LVjnmYKt/dev-board
